.. _getting-help:

Getting help
------------

Using MUSE can be daunting at first. It is a very powerful tool, but unleashing all its capabilities might take some time and effort. There are several resources available to help you with that:

- :ref:`customising-muse`: The tutorials - and the underlying code, `available in the GitHub repository <https://github.com/EnergySystemsModellingLab/MUSE_OS/tree/main/docs/tutorial-code>`_ - are the easiest way to start using MUSE and adapting it to your own needs. Look for one that looks similar to what you will need and use it as the starting point of your own simulation.

- The `MUSE users mailing list <https://groups.google.com/g/muse-model>`_ is your next stop to get help with MUSE. Have a look at past topics in case anyone has hit the same issue as you or open your own questions if nothing fits what you are looking for.

- `GitHub Issues <https://github.com/EnergySystemsModellingLab/MUSE_OS/issues>`_: Sometimes, the questions you are having are related to functionality that is simply not in MUSE - or even to a bug! In that case, having a look at the issues (past and still open) might help you solve your problem or steer you in the right direction.

- `Opening a bug report in GitHub <https://github.com/EnergySystemsModellingLab/MUSE_OS/issues/new?assignees=&labels=bug&projects=&template=bug_report.md&title=%5BBUG%5D+>`_ is the right move if you are sure you have found something in MUSE that is plainly wrong. In such a complex, it is not unusual to find errors and counting with the collaboration of the community to spot them is essential to keep improving. Ideally, before opening a bug report, send your problem to the mailing list in case someone has already found that issue and has a solution for it or, on the contrary, can confirm that is indeed a bug. Keep in mind that it will take a while for bugs to be fixed, so this will rarely be a short term source of support. **You will need a GitHub account (it is free) to open a bug report**.

- `Open a feature request in GitHub <https://github.com/EnergySystemsModellingLab/MUSE_OS/issues/new?assignees=&labels=enhancement&projects=&template=feature_request.md&title=>`_ if, despite al the functionality built in MUSE, there is something that is missing and that you think will be useful. As before, it would be ideal if this is sent before to the mailing list to get an idea of the appetite for such a new feature in the community. **You will need a GitHub account (it is free) to open a feature request**.
